/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2011 ForTISS GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.kernel.ui;

import org.eclipse.jface.resource.ImageDescriptor;
import org.eclipse.jface.resource.ImageRegistry;
import org.eclipse.ui.plugin.AbstractUIPlugin;
import org.fortiss.tooling.kernel.ui.service.IActionService;
import org.fortiss.tooling.kernel.ui.service.IAllocationEditPartFactoryService;
import org.fortiss.tooling.kernel.ui.service.IContextMenuService;
import org.fortiss.tooling.kernel.ui.service.IEditPartFactoryService;
import org.fortiss.tooling.kernel.ui.service.IMarkerService;
import org.fortiss.tooling.kernel.ui.service.IModelEditorBindingService;
import org.fortiss.tooling.kernel.ui.service.IModelElementHandlerService;
import org.fortiss.tooling.kernel.ui.service.INavigatorService;
import org.osgi.framework.BundleContext;

/**
 * The activator class controls the plug-in life cycle.
 * 
 * @author hoelzl
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating YELLOW Hash: E478C03126855DDDA93A7B1C83B61EFA
 */
public class ToolingKernelUIActivator extends AbstractUIPlugin {

	/** The plug-in ID. */
	public static final String PLUGIN_ID = ToolingKernelUIActivator.class.getPackage().getName(); //$NON-NLS-1$

	/** The shared instance. */
	private static ToolingKernelUIActivator plugin;

	/** {@inheritDoc} */
	@Override
	public void start(BundleContext context) throws Exception {
		super.start(context);
		plugin = this;

		initializeServices();
	}

	/** Initializes UI services by calling its singleton reference {@code toString()}. */
	private void initializeServices() {
		IActionService.INSTANCE.toString();
		IAllocationEditPartFactoryService.INSTANCE.toString();
		IContextMenuService.INSTANCE.toString();
		// FIXME: IConstraintVerificationUIService.INSTANCE.toString();
		IEditPartFactoryService.INSTANCE.toString();
		IMarkerService.INSTANCE.toString();
		IModelEditorBindingService.INSTANCE.toString();
		IModelElementHandlerService.INSTANCE.toString();
		INavigatorService.INSTANCE.toString();
	}

	/** {@inheritDoc} */
	@Override
	public void stop(BundleContext context) throws Exception {
		getImageRegistry().dispose();
		plugin = null;
		super.stop(context);
	}

	/** Returns the shared instance. */
	public static ToolingKernelUIActivator getDefault() {
		return plugin;
	}

	/** Returns image descriptor of the image in the kernel plugin. */
	public static ImageDescriptor getImageDescriptor(String iconPath) {
		return imageDescriptorFromPlugin(PLUGIN_ID, iconPath);
	}

	/** {@inheritDoc} */
	@Override
	protected void initializeImageRegistry(ImageRegistry registry) {
		ESharedImages.registerImages(registry);
	}
}
